@@ -77,7 +77,7 @@ def analyse_dataset(from_data, sample_settings=None):
         data_preparation = {},
         predict_columns = [],
         empty_columns = [],
-        handle_foreign_keys = True,
+        force_column_usage = [],
         force_categorical_encoding = [],
         data_types = {},
         data_subtypes = {},
